@@ -8,13 +8,14 @@ checks and manipulations a bit easier.
 Documentation and Examples: https://github.com/miku/marcx
 """
 
-from pymarc.record import Record, Field
 from pymarc.exceptions import FieldNotFound
+from pymarc.record import Record, Field
+import collections
+import itertools
 import pyisbn
 import re
-import itertools
 
-__version__ = '0.1.6'
+__version__ = '0.1.7'
 
 __all__ = [
     'FatRecord',
@@ -29,13 +30,15 @@ __all__ = [
     'FincMarc',
 ]
 
+
 def pairwise(iterable):
     """
     http://docs.python.org/2/library/itertools.html#recipes
     s -> (s0, s1), (s1, s2), (s2, s3), ...
     """
-    a = iter(iterable)
-    return itertools.izip(a, a)
+    it = iter(iterable)
+    return itertools.izip(it, it)
+
 
 def _equals(value):
     """ equality """
@@ -82,7 +85,8 @@ def valuegetter(*fieldspecs, **kwargs):
 
     >>> from marcx import FatRecord, valuegetter
     >>> from urllib import urlopen
-    >>> record = FatRecord(data=urlopen("https://raw.github.com/edsu/pymarc/master/test/marc.dat").read())
+    >>> record = FatRecord(data=urlopen(
+    ...    "https://raw.github.com/edsu/pymarc/master/test/marc.dat").read())
 
     In two steps:
 
@@ -183,6 +187,17 @@ class FatRecord(Record):
     def __init__(self, *args, **kwargs):
         super(FatRecord, self).__init__(*args, **kwargs)
 
+    @classmethod
+    def from_record(cls, record):
+        if not isinstance(record, Record):
+            raise TypeError('record must be of type pymarc.Record')
+        record.__class__ = FatRecord
+        return record
+
+    def to_record(self):
+        self.__class__ = Record
+        return self
+
     def add(self, tag, data=None, indicators=None, **kwargs):
         """ Add a field to a record. Example:
 
@@ -211,9 +226,18 @@ class FatRecord(Record):
         if data:  # == control field (001 -- 009)
             field = Field(tag, data=data)
         else:     # == non-control field (010 -- 999)
-            # rewrite the kwargs to include numerical kwargs like, `_9`
-            subfields = [e for sl in [(k.replace('_', ''), v) 
-                           for k, v in kwargs.iteritems()] for e in sl]
+            subfields = []
+            for key, value in kwargs.iteritems():
+                key = key.replace('_', '')
+                if isinstance(value, basestring):
+                    subfields += [key, value]
+                elif isinstance(value, collections.Iterable):
+                    for val in value:
+                        if not isinstance(val, basestring):
+                            raise ValueError('subfield values must be strings')
+                        subfields += [key, val]
+                else:
+                    raise ValueError('subfield values must be strings')
             field = Field(tag, indicators, subfields=subfields)
         self.add_field(field)
 
@@ -252,7 +276,7 @@ class FatRecord(Record):
         argument `default` if not value exists. `default` defaults to `None`.
         """
         default = kwargs.get('default', None)
-        values = [ val for val in self.itervalues(*fieldspecs, **kwargs) ]
+        values = [val for val in self.itervalues(*fieldspecs, **kwargs)]
         if values:
             return values[0]
         else:
@@ -274,12 +298,12 @@ class FatRecord(Record):
         `fun(value)` evaluates to `True`.
 
         The real signature is like:
-        
+
             remove_field_if(self, fieldspec, fun):
 
         but a variable number of fieldspecs can be added,
-        so we have to resort to `*args` and figure out, which one is a function,
-        by asking if the argument is `callable`.
+        so we have to resort to `*args` and figure out, which one is
+        a function, by asking if the argument is `callable`.
 
         Example:
 
@@ -305,10 +329,10 @@ class FatRecord(Record):
         >>> print(record)
         =LDR            22        4500
         =020  \\$a11111111
-    
+
         """
         fieldspecs = set()
-        function = lambda val: val
+        function = lambda val: False
         for arg in args:
             if callable(arg):
                 function = arg
@@ -316,7 +340,8 @@ class FatRecord(Record):
                 fieldspecs.add(arg)
             else:
                 raise ValueError('argument must be callable (test function) '
-                    'or basestring (fieldspec, like 020.a or 856.u, etc.)')
+                                 'or basestring (fieldspec, like 020.a '
+                                 'or 856.u, etc.)')
         removed = []
         for field, value in fieldgetter(*fieldspecs)(self):
             if function(value):
@@ -357,7 +382,8 @@ class FatRecord(Record):
                 fieldspecs.add(arg)
             else:
                 raise ValueError('argument must be callable (test function) '
-                    'or basestring (fieldspec, like 020.a or 856.u, etc.)')
+                                 'or basestring (fieldspec, like 020.a '
+                                 'or 856.u, etc.)')
         if kwargs.get('all', False):
             return min(
                 [function(value) for value in valuegetter(*fieldspecs)(self)])
